@@ -1,7 +1,7 @@
 
 """used to give representation of objects in xml format
 	
-def repr(arg1, *children, level=0, **props):
+def repr(arg1, level=None, props=None, children=None):
 	the function has three uses:
 		1. same as built-in repr function when arg1
 		doesn't implement __xml__ method.
@@ -36,12 +36,16 @@ def repr(arg1, *children, level=0, **props):
 """
 
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 __all__ = ['repr']
 
 
-def repr(arg1, *children, level=0, **props):
+def repr(arg1, level=None, props=None, children=None):
 	if type(arg1) != str:
+		if level is None:
+			# 'level' is optional
+			level = 0
+		
 		if '__xml__' in dir(arg1):
 			# calling '__xml__' method if implemented
 			return arg1.__xml__(level)
@@ -53,6 +57,9 @@ def repr(arg1, *children, level=0, **props):
 			else: # ModuleType
 				return builtins.repr(arg1)
 	
+	if level is None:
+		# 'level' is required
+		raise TypeError("level parameter is missing")
 	#=====#=====#=====#=====#=====#=====#=====#
 	# 'name', 'indent' and 'props' variables
 	name = arg1
@@ -60,7 +67,7 @@ def repr(arg1, *children, level=0, **props):
 	props = ' '.join(
 		'%s="%s"' % item if item[1] != True else item[0]
 		for item in props.items() if item[1] != False
-	)
+	) if props else '\b'
 	
 	# returning xml tag string
 	if children:
